### Przykładowy skrypt tworzący wykresy i tabele. Wykresy i tabele są
### eksporotwane w taki sposób aby można je było łatwo włączyć do
### dokumenty LaTeXowego.

### Biblioteki
library(stargazer)
library(dplyr)

### Parametry skryptu. Założenie jest takie, że katalog roboczy
### pokrywa się z głównym katalogiem repozytorium. Jeżeli tak nie jest
### to należy zmienić ścieżki (albo katalog roboczy).
figDir <- "./paper/figs/"
tabDir <- "./paper/tabs/"

### Przykładowa ramka danych
n <- 10^3
d <- tibble(
  x = rnorm(n),
  y = 1 + 2 * x + rnorm(n),
  class = ifelse(y > 1 + 2 * x, "Up", "Down")
)

### Eksport kilku obserwacji aby w pracy można było pokazać strukturę
### danych.
d1 <- d[1:5, ] %>%
  mutate("Values x" = round(x, 2), "Values y" = round(y, 2), "Class" = class) %>%
  select("Values x", "Values y", "Class")
stargazer(d1,
          float = FALSE,
          summary = FALSE,
          out = paste0(tabDir, "tab_00.tex"))

### Prosta wizualizacja danych.
with(d, {
  plot(x, y,
       main = "Example dataset",
       pch = ifelse(class == "Up", 20, 4),
       col = ifelse(class == "Up", rgb(1, 0, 0, .4), rgb(0, 0, 1, .5)))
})
dev.copy(device = png, "./paper/figs/fig_00.png")
dev.off()

### Model regresji liniowej.
model <- lm(y ~ +1 +x, data = d)

### Eksport tabeli podsumowującej model regresji liniowej.
stargazer(model,
          float = FALSE,
          summary = TRUE,
          out = paste0(tabDir, "tab_01.tex"))

### Inna przykładowa wizualizacja.
with(d, {
  plot(x, y,
       main = "Example dataset",
       pch = ifelse(class == "Up", 20, 4),
       col = ifelse(class == "Up", rgb(1, 0, 0, .4), rgb(0, 0, 1, .5)))
  abline(model, lwd = 2, col = "magenta")
})
dev.copy(device = png, "./paper/figs/fig_01.png")
dev.off()

